@@ -1,4 +1,4 @@
-# $Revision: 1.31 $$Date: 2005-07-27 09:55:32 -0400 (Wed, 27 Jul 2005) $$Author: wsnyder $
+# $Id: Enum.pm 6461 2005-09-20 18:28:58Z wsnyder $
 # Author: Wilson Snyder <wsnyder@wsnyder.org>
 ######################################################################
 #
@@ -21,7 +21,7 @@ use Verilog::Language;	# For value parsing
 use strict;
 use vars qw (@ISA $VERSION);
 @ISA = qw (SystemC::Vregs::Subclass);
-$VERSION = '1.301';
+$VERSION = '1.310';
 
 ######################################################################
 ######################################################################
@@ -95,6 +95,16 @@ sub fields_sorted {
 	    (values %{$typeref->{fields}}));
 }
 
+sub fields_first_name {
+    my $self = shift;
+    my @fields = $self->fields_sorted;
+    if ($fields[0]) {
+	return $fields[0]->name;
+    } else {
+	return undef;
+    }
+}
+
 sub dump {
     my $self = shift;
     my $fh = shift || \*STDOUT;
@@ -118,6 +128,7 @@ use vars qw (@ISA);
 @ISA = qw (SystemC::Vregs::Subclass);
 
 # Fields: 	name, at, class
+sub name { return $_[0]->{name}; }
 
 sub new {
     my $class = shift;
