@@ -1,14 +1,15 @@
-# $Revision: 1.15 $$Date: 2005-06-17 14:45:25 -0400 (Fri, 17 Jun 2005) $$Author: wsnyder $
+# $Id: test_utils.pl 5416 2005-08-25 12:47:15Z wsnyder $
 # DESCRIPTION: Perl ExtUtils: Common routines required by package tests
 #
 # Copyright 2001-2005 by Wilson Snyder.  This program is free software;
 # you can redistribute it and/or modify it under the terms of either the GNU
 # General Public License or the Perl Artistic License.
 
-use vars qw($PERL $GCC);
+use vars qw($PERL $GCC $GCCC);
 
 $PERL = "$^X -Iblib/arch -Iblib/lib";
 $GCC  = "g++ -Wall -Werror -I. -I../t -I../include ";
+$GCCC = "gcc -Wall -Werror -I. -I../t -I../include ";
 
 mkdir 'test_dir',0777;
 
